diax
----

This is a python module for interacting with 3DIAX, Authentise's 3D printing API. It's public - we mostly just use it to test stuff.

CHANGELOG
---------

1.5
---
Add support for token authentication, disabling SSL verification, and the ability to list resources from the CLI

1.4
---
Add support for synchronous generation of events to diax client via client.streamevents()

1.3
---
Add asyncio-based client. It's experimental for now and not very complete

1.2
---
Add basic CLI with client-side validation for doing general operations with diax

1.1
---
Allow login, pull credentials from a well-known file

1.0
---
Initial release, does, literally, nothing.
